@@ -1,11 +1,12 @@
-import os
 import json
+import os
+
 import pytest
 
-import unstructured.utils as utils
+from unstructured import utils
 
 
-@pytest.fixture
+@pytest.fixture()
 def input_data():
     return [
         {"text": "This is a sentence."},
@@ -13,12 +14,12 @@ def input_data():
     ]
 
 
-@pytest.fixture
+@pytest.fixture()
 def output_jsonl_file(tmp_path):
     return os.path.join(tmp_path, "output.jsonl")
 
 
-@pytest.fixture
+@pytest.fixture()
 def input_jsonl_file(tmp_path, input_data):
     file_path = os.path.join(tmp_path, "input.jsonl")
     with open(file_path, "w+") as input_file:
@@ -28,7 +29,7 @@ def input_jsonl_file(tmp_path, input_data):
 
 def test_save_as_jsonl(input_data, output_jsonl_file):
     utils.save_as_jsonl(input_data, output_jsonl_file)
-    with open(output_jsonl_file, "r") as output_file:
+    with open(output_jsonl_file) as output_file:
         file_data = [json.loads(line) for line in output_file]
     assert file_data == input_data
 
