@@ -1,14 +1,19 @@
-from enum import Enum
 import os
-from typing import IO, Optional
 import zipfile
+from enum import Enum
+from typing import IO, Optional
+
+try:
+    import magic
+
+    LIBMAGIC_AVAILABLE = True
+except ImportError:  # pragma: nocover
+    LIBMAGIC_AVAILABLE = False  # pragma: nocover
 
-import magic
 
 from unstructured.logger import logger
 from unstructured.nlp.patterns import EMAIL_HEAD_RE
 
-
 DOCX_MIME_TYPES = [
     "application/vnd.openxmlformats-officedocument.wordprocessingml.document",
 ]
@@ -33,6 +38,11 @@ PPT_MIME_TYPES = [
     "application/vnd.ms-powerpoint",
 ]
 
+MD_MIME_TYPES = [
+    "text/markdown",
+    "text/x-markdown",
+]
+
 # NOTE(robinson) - .docx.xlsx files are actually zip file with a .docx/.xslx extension.
 # If the MIME type is application/octet-stream, we check if it's a .docx/.xlsx file by
 # looking for expected filenames within the zip file.
@@ -78,6 +88,7 @@ class FileType(Enum):
     # Markup Types
     HTML = 50
     XML = 51
+    MD = 52
 
     # Compressed Types
     ZIP = 60
@@ -91,10 +102,13 @@ EXT_TO_FILETYPE = {
     ".pdf": FileType.PDF,
     ".docx": FileType.DOCX,
     ".jpg": FileType.JPG,
+    ".jpeg": FileType.JPG,
     ".txt": FileType.TXT,
+    ".text": FileType.TXT,
     ".eml": FileType.EML,
     ".xml": FileType.XML,
     ".html": FileType.HTML,
+    ".md": FileType.MD,
     ".xlsx": FileType.XLSX,
     ".pptx": FileType.PPTX,
     ".png": FileType.PNG,
@@ -107,7 +121,8 @@ EXT_TO_FILETYPE = {
 
 
 def detect_filetype(
-    filename: Optional[str] = None, file: Optional[IO] = None
+    filename: Optional[str] = None,
+    file: Optional[IO] = None,
 ) -> Optional[FileType]:
     """Use libmagic to determine a file's type. Helps determine which partition brick
     to use for a given file. A return value of None indicates a non-supported file type."""
@@ -117,13 +132,23 @@ def detect_filetype(
     if filename:
         _, extension = os.path.splitext(filename)
         extension = extension.lower()
-        mime_type = magic.from_file(filename, mime=True)
+        if LIBMAGIC_AVAILABLE:
+            mime_type = magic.from_file(filename, mime=True)
+        else:
+            return EXT_TO_FILETYPE.get(extension.lower(), FileType.UNK)
     elif file is not None:
         extension = None
         # NOTE(robinson) - the python-magic docs recommend reading at least the first 2048 bytes
         # Increased to 4096 because otherwise .xlsx files get detected as a zip file
         # ref: https://github.com/ahupp/python-magic#usage
-        mime_type = magic.from_buffer(file.read(4096), mime=True)
+        if LIBMAGIC_AVAILABLE:
+            mime_type = magic.from_buffer(file.read(4096), mime=True)
+        else:
+            raise ImportError(
+                "libmagic is unavailable. "
+                "Filetype detection on file-like objects requires libmagic. "
+                "Please install libmagic and try again.",
+            )
     else:
         raise ValueError("No filename nor file were specified.")
 
@@ -142,16 +167,18 @@ def detect_filetype(
     elif mime_type == "image/png":
         return FileType.PNG
 
+    elif mime_type in MD_MIME_TYPES:
+        # NOTE - I am not sure whether libmagic ever returns these mimetypes.
+        return FileType.MD
+
     elif mime_type == "text/plain":
         if extension and extension == ".eml":
             return FileType.EML
-        if file and not extension:
-            if _check_eml_from_buffer(file=file) is True:
-                return FileType.EML
-            else:
-                return FileType.TXT
-        else:
-            return FileType.TXT
+        if extension and extension == ".md":
+            return FileType.MD
+        if file and not extension and _check_eml_from_buffer(file=file) is True:
+            return FileType.EML
+        return FileType.TXT
 
     elif mime_type.endswith("xml"):
         if extension and extension == ".html":
@@ -197,7 +224,7 @@ def detect_filetype(
             return filetype
 
     logger.warn(
-        f"MIME type was {mime_type}. This file type is not currently supported in unstructured."
+        f"MIME type was {mime_type}. This file type is not currently supported in unstructured.",
     )
     return FileType.UNK
 
@@ -217,7 +244,7 @@ def _detect_filetype_from_octet_stream(file: IO) -> FileType:
         elif all([f in archive_filenames for f in EXPECTED_PPTX_FILES]):
             return FileType.PPTX
 
-    logger.warning("Could not detect the filetype from application/octet-strem MIME type.")
+    logger.warning("Could not detect the filetype from application/octet-stream MIME type.")
     return FileType.UNK
 
 
