@@ -8,7 +8,9 @@ from unstructured.partition.pptx import partition_pptx
 
 
 def partition_ppt(
-    filename: Optional[str] = None, file: Optional[IO] = None, include_page_breaks: bool = False
+    filename: Optional[str] = None,
+    file: Optional[IO] = None,
+    include_page_breaks: bool = False,
 ) -> List[Element]:
     """Partitions Microsoft PowerPoint Documents in .ppt format into their document elements.
 
